@@ -441,7 +441,7 @@ void W_choose_order_1(vector<string> vy, unsigned long int lvy, vector<unsigned
    np=np+vc[i]+vn[i];
   }
   
-  if(nnodes<lvy){
+  if(nnodes<np){
   
    nchannels_sim=0;
     
